import { PythonObject } from '../types/python-object';
import * as tf from '@tensorflow/tfjs-node-gpu';
/**
 * @class main class representing a python instance.
 */
export default class Python {
    scope: string;
    statements: string[];
    static pythons: Python[];
    /**
     *
     * @param python Python instance
     */
    static constructPythonStatements(python: Python, user_expressions?: any): Promise<unknown>;
    /**
     * static method: bind python-node codes into some scope which is associated to one ipyhton kernel
     * @param scope scope name
     * @param callback python-node codes
     */
    static scope(scope: string, callback: Function): Promise<void>;
    /**
     * used for named arguments
     */
    nA: (arg: any) => any;
    /** */
    static exit: (scope: string) => Promise<void>;
    /**
     * convert raw PythonObject into its identifier representation which is used in python kernel
     */
    static convert: (object: PythonObject) => any;
    /**
     * run shell commands, same as ! operator in ipython kernel
     */
    runshell: (shell: string) => void;
    /**
     * import package
     */
    import: (packageName: string) => PythonObject;
    /**
     * install pacakge
     * @param packageName: name of package
     * @param version: version of package, default to latest
     */
    install: (packageName: string, version?: string) => void;
    /**
     * run some python built in function.
     * @param functionName: build-in function name
     * @param object: argument. now just support 1
     */
    buildin: (functionName: string, object: PythonObject) => PythonObject;
    /**
     * same as from ... import ... in python
     * @param packageName name of the package
     * @param importNames names to be imported
     */
    fromImport(packageName: string, importNames: string[]): PythonObject[];
    /**
     * create python number
     */
    createNumber: (number: number) => PythonObject;
    /**
     * create python string
     */
    createString: (string: string, isRaw?: boolean) => PythonObject;
    /**
     * create python boolean type
     */
    createBoolean: (value: boolean) => PythonObject;
    /**
     * create python none
     */
    createNone: () => PythonObject;
    /**
     * create python tuple
     */
    createTuple: (value: any[]) => PythonObject;
    /**
     * create python list
     */
    createList: (value: any[]) => PythonObject;
    /**
     * create python set
     */
    createSet: (value: any[]) => PythonObject;
    /**
     * create python dictionary
     */
    createDictionary: (value: any) => PythonObject;
    /**
     * print in python
     */
    print: (object: PythonObject) => void;
    /**
     * same as a == b in python
     */
    equal: (object1: PythonObject, object2: PythonObject) => PythonObject;
    /**
     * same as a!=b in python
     */
    notEqual: (object1: PythonObject, object2: PythonObject) => PythonObject;
    /**
     * same as a > b in python
     */
    larger: (object1: PythonObject, object2: PythonObject) => PythonObject;
    /**
     * same as a < b in python
     */
    smaller: (object1: PythonObject, object2: PythonObject) => PythonObject;
    /**
     * same as a >= b in python
     */
    largerEqual: (object1: PythonObject, object2: PythonObject) => PythonObject;
    /**
     * same as a <= b in python
     */
    smallerEqual: (object1: PythonObject, object2: PythonObject) => PythonObject;
    /**
     * same as a and b in python
     */
    and: (object1: PythonObject, object2: PythonObject) => PythonObject;
    /**
     * same as a or b in python
     */
    or: (object1: PythonObject, object2: PythonObject) => PythonObject;
    /**
     * same not a in python
     */
    not: (object: PythonObject) => PythonObject;
    /**
     * if statement
     * @param condition if condition
     * @param execution if body expression
     */
    if: (condition: PythonObject, execution: Function) => void;
    /**
     * same as a + b in python
     */
    add: (object1: PythonObject, object2: PythonObject) => PythonObject;
    /**
     * same as a - b in python
     */
    minus: (object1: PythonObject, object2: PythonObject) => PythonObject;
    /**
     * same as a * b in python
     */
    multiply: (object1: PythonObject, object2: PythonObject) => PythonObject;
    /**
     * same as a / b in python
     */
    divide: (object1: PythonObject, object2: PythonObject) => PythonObject;
    /**
     * same as a % b in python
     */
    mod: (object1: PythonObject, object2: PythonObject) => PythonObject;
    /**
     * same as a ** b in python
     */
    pow: (object1: PythonObject, object2: PythonObject) => PythonObject;
    /**
     * same as a // b in python
     */
    floorDivide: (object1: PythonObject, object2: PythonObject) => PythonObject;
    /**
     * this is for those cases where above functions does not meet user's requirements.
     * This is to run the raw python statement.
     * Please use convert method to convert PythonObject to its identifier when use this method
     */
    runRaw: (raw: string) => PythonObject;
    evaluate: (object: PythonObject) => Promise<{
        type: any;
        value: any;
    }>;
    createNumpyFromTf: (tensor: tf.Tensor<tf.Rank>) => PythonObject;
    reconnect: () => Promise<void>;
}
